Pandas Extension
===============================

version number: 0.0.3
author: Harrison Mamin

Overview
--------

Tools for exploratory data analysis with Pandas

Installation / Usage
--------------------

To install use pip:

    $ pip install pandas_htools

Or clone the repo:

    $ git clone https://github.com/hdmamin/pandas_htools.git
    $ python setup.py install
    
Example
-------

TBD
